# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['V3ProvisionConfigArgs', 'V3ProvisionConfig']

@pulumi.input_type
class V3ProvisionConfigArgs:
    def __init__(__self__, *,
                 function_name: pulumi.Input[str],
                 always_allocate_cpu: Optional[pulumi.Input[bool]] = None,
                 always_allocate_gpu: Optional[pulumi.Input[bool]] = None,
                 qualifier: Optional[pulumi.Input[str]] = None,
                 scheduled_actions: Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigScheduledActionArgs']]]] = None,
                 target: Optional[pulumi.Input[int]] = None,
                 target_tracking_policies: Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigTargetTrackingPolicyArgs']]]] = None):
        """
        The set of arguments for constructing a V3ProvisionConfig resource.
        :param pulumi.Input[str] function_name: The name of the function. If this parameter is not specified, the provisioned configurations of all functions are listed.
        :param pulumi.Input[bool] always_allocate_cpu: Whether the CPU is always allocated. The default value is true.
        :param pulumi.Input[bool] always_allocate_gpu: Whether to always assign GPU to function instance
        :param pulumi.Input[str] qualifier: The function alias or LATEST.
        :param pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigScheduledActionArgs']]] scheduled_actions: Timing policy configuration See `scheduled_actions` below.
        :param pulumi.Input[int] target: Number of reserved target resources. The value range is [0,10000].
        :param pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigTargetTrackingPolicyArgs']]] target_tracking_policies: Metric tracking scaling policy configuration See `target_tracking_policies` below.
        """
        pulumi.set(__self__, "function_name", function_name)
        if always_allocate_cpu is not None:
            pulumi.set(__self__, "always_allocate_cpu", always_allocate_cpu)
        if always_allocate_gpu is not None:
            pulumi.set(__self__, "always_allocate_gpu", always_allocate_gpu)
        if qualifier is not None:
            pulumi.set(__self__, "qualifier", qualifier)
        if scheduled_actions is not None:
            pulumi.set(__self__, "scheduled_actions", scheduled_actions)
        if target is not None:
            pulumi.set(__self__, "target", target)
        if target_tracking_policies is not None:
            pulumi.set(__self__, "target_tracking_policies", target_tracking_policies)

    @property
    @pulumi.getter(name="functionName")
    def function_name(self) -> pulumi.Input[str]:
        """
        The name of the function. If this parameter is not specified, the provisioned configurations of all functions are listed.
        """
        return pulumi.get(self, "function_name")

    @function_name.setter
    def function_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "function_name", value)

    @property
    @pulumi.getter(name="alwaysAllocateCpu")
    def always_allocate_cpu(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the CPU is always allocated. The default value is true.
        """
        return pulumi.get(self, "always_allocate_cpu")

    @always_allocate_cpu.setter
    def always_allocate_cpu(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "always_allocate_cpu", value)

    @property
    @pulumi.getter(name="alwaysAllocateGpu")
    def always_allocate_gpu(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to always assign GPU to function instance
        """
        return pulumi.get(self, "always_allocate_gpu")

    @always_allocate_gpu.setter
    def always_allocate_gpu(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "always_allocate_gpu", value)

    @property
    @pulumi.getter
    def qualifier(self) -> Optional[pulumi.Input[str]]:
        """
        The function alias or LATEST.
        """
        return pulumi.get(self, "qualifier")

    @qualifier.setter
    def qualifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualifier", value)

    @property
    @pulumi.getter(name="scheduledActions")
    def scheduled_actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigScheduledActionArgs']]]]:
        """
        Timing policy configuration See `scheduled_actions` below.
        """
        return pulumi.get(self, "scheduled_actions")

    @scheduled_actions.setter
    def scheduled_actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigScheduledActionArgs']]]]):
        pulumi.set(self, "scheduled_actions", value)

    @property
    @pulumi.getter
    def target(self) -> Optional[pulumi.Input[int]]:
        """
        Number of reserved target resources. The value range is [0,10000].
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter(name="targetTrackingPolicies")
    def target_tracking_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigTargetTrackingPolicyArgs']]]]:
        """
        Metric tracking scaling policy configuration See `target_tracking_policies` below.
        """
        return pulumi.get(self, "target_tracking_policies")

    @target_tracking_policies.setter
    def target_tracking_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigTargetTrackingPolicyArgs']]]]):
        pulumi.set(self, "target_tracking_policies", value)


@pulumi.input_type
class _V3ProvisionConfigState:
    def __init__(__self__, *,
                 always_allocate_cpu: Optional[pulumi.Input[bool]] = None,
                 always_allocate_gpu: Optional[pulumi.Input[bool]] = None,
                 current: Optional[pulumi.Input[int]] = None,
                 current_error: Optional[pulumi.Input[str]] = None,
                 function_arn: Optional[pulumi.Input[str]] = None,
                 function_name: Optional[pulumi.Input[str]] = None,
                 qualifier: Optional[pulumi.Input[str]] = None,
                 scheduled_actions: Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigScheduledActionArgs']]]] = None,
                 target: Optional[pulumi.Input[int]] = None,
                 target_tracking_policies: Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigTargetTrackingPolicyArgs']]]] = None):
        """
        Input properties used for looking up and filtering V3ProvisionConfig resources.
        :param pulumi.Input[bool] always_allocate_cpu: Whether the CPU is always allocated. The default value is true.
        :param pulumi.Input[bool] always_allocate_gpu: Whether to always assign GPU to function instance
        :param pulumi.Input[int] current: (Available since v1.234.0) Number of actual resources
        :param pulumi.Input[str] current_error: (Available since v1.234.0) Error message when a Reserved Instance creation fails
        :param pulumi.Input[str] function_arn: (Available since v1.234.0) Resource Description of the function
        :param pulumi.Input[str] function_name: The name of the function. If this parameter is not specified, the provisioned configurations of all functions are listed.
        :param pulumi.Input[str] qualifier: The function alias or LATEST.
        :param pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigScheduledActionArgs']]] scheduled_actions: Timing policy configuration See `scheduled_actions` below.
        :param pulumi.Input[int] target: Number of reserved target resources. The value range is [0,10000].
        :param pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigTargetTrackingPolicyArgs']]] target_tracking_policies: Metric tracking scaling policy configuration See `target_tracking_policies` below.
        """
        if always_allocate_cpu is not None:
            pulumi.set(__self__, "always_allocate_cpu", always_allocate_cpu)
        if always_allocate_gpu is not None:
            pulumi.set(__self__, "always_allocate_gpu", always_allocate_gpu)
        if current is not None:
            pulumi.set(__self__, "current", current)
        if current_error is not None:
            pulumi.set(__self__, "current_error", current_error)
        if function_arn is not None:
            pulumi.set(__self__, "function_arn", function_arn)
        if function_name is not None:
            pulumi.set(__self__, "function_name", function_name)
        if qualifier is not None:
            pulumi.set(__self__, "qualifier", qualifier)
        if scheduled_actions is not None:
            pulumi.set(__self__, "scheduled_actions", scheduled_actions)
        if target is not None:
            pulumi.set(__self__, "target", target)
        if target_tracking_policies is not None:
            pulumi.set(__self__, "target_tracking_policies", target_tracking_policies)

    @property
    @pulumi.getter(name="alwaysAllocateCpu")
    def always_allocate_cpu(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the CPU is always allocated. The default value is true.
        """
        return pulumi.get(self, "always_allocate_cpu")

    @always_allocate_cpu.setter
    def always_allocate_cpu(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "always_allocate_cpu", value)

    @property
    @pulumi.getter(name="alwaysAllocateGpu")
    def always_allocate_gpu(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to always assign GPU to function instance
        """
        return pulumi.get(self, "always_allocate_gpu")

    @always_allocate_gpu.setter
    def always_allocate_gpu(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "always_allocate_gpu", value)

    @property
    @pulumi.getter
    def current(self) -> Optional[pulumi.Input[int]]:
        """
        (Available since v1.234.0) Number of actual resources
        """
        return pulumi.get(self, "current")

    @current.setter
    def current(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "current", value)

    @property
    @pulumi.getter(name="currentError")
    def current_error(self) -> Optional[pulumi.Input[str]]:
        """
        (Available since v1.234.0) Error message when a Reserved Instance creation fails
        """
        return pulumi.get(self, "current_error")

    @current_error.setter
    def current_error(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "current_error", value)

    @property
    @pulumi.getter(name="functionArn")
    def function_arn(self) -> Optional[pulumi.Input[str]]:
        """
        (Available since v1.234.0) Resource Description of the function
        """
        return pulumi.get(self, "function_arn")

    @function_arn.setter
    def function_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "function_arn", value)

    @property
    @pulumi.getter(name="functionName")
    def function_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the function. If this parameter is not specified, the provisioned configurations of all functions are listed.
        """
        return pulumi.get(self, "function_name")

    @function_name.setter
    def function_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "function_name", value)

    @property
    @pulumi.getter
    def qualifier(self) -> Optional[pulumi.Input[str]]:
        """
        The function alias or LATEST.
        """
        return pulumi.get(self, "qualifier")

    @qualifier.setter
    def qualifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualifier", value)

    @property
    @pulumi.getter(name="scheduledActions")
    def scheduled_actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigScheduledActionArgs']]]]:
        """
        Timing policy configuration See `scheduled_actions` below.
        """
        return pulumi.get(self, "scheduled_actions")

    @scheduled_actions.setter
    def scheduled_actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigScheduledActionArgs']]]]):
        pulumi.set(self, "scheduled_actions", value)

    @property
    @pulumi.getter
    def target(self) -> Optional[pulumi.Input[int]]:
        """
        Number of reserved target resources. The value range is [0,10000].
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter(name="targetTrackingPolicies")
    def target_tracking_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigTargetTrackingPolicyArgs']]]]:
        """
        Metric tracking scaling policy configuration See `target_tracking_policies` below.
        """
        return pulumi.get(self, "target_tracking_policies")

    @target_tracking_policies.setter
    def target_tracking_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['V3ProvisionConfigTargetTrackingPolicyArgs']]]]):
        pulumi.set(self, "target_tracking_policies", value)


class V3ProvisionConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 always_allocate_cpu: Optional[pulumi.Input[bool]] = None,
                 always_allocate_gpu: Optional[pulumi.Input[bool]] = None,
                 function_name: Optional[pulumi.Input[str]] = None,
                 qualifier: Optional[pulumi.Input[str]] = None,
                 scheduled_actions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['V3ProvisionConfigScheduledActionArgs', 'V3ProvisionConfigScheduledActionArgsDict']]]]] = None,
                 target: Optional[pulumi.Input[int]] = None,
                 target_tracking_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['V3ProvisionConfigTargetTrackingPolicyArgs', 'V3ProvisionConfigTargetTrackingPolicyArgsDict']]]]] = None,
                 __props__=None):
        """
        Provides a FCV3 Provision Config resource.

        Function Reservation Configuration.

        For information about FCV3 Provision Config and how to use it, see [What is Provision Config](https://www.alibabacloud.com/help/en/functioncompute/fc-3-0/developer-reference/api-fc-2023-03-30-putprovisionconfig).

        > **NOTE:** Available since v1.230.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random
        import pulumi_time as time

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_project = alicloud.log.Project("default",
            project_name=f"{name}-{default['result']}",
            description=name)
        default_store = alicloud.log.Store("default",
            project_name=default_project.name,
            logstore_name=f"{name}-{default['result']}",
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        wait10_minutes = time.index.Sleep("wait_10_minutes", create_duration=10m,
        opts = pulumi.ResourceOptions(depends_on=[default_store]))
        function = alicloud.fc.V3Function("function",
            memory_size=512,
            cpu=0.5,
            handler="index.handler",
            function_name=f"{name}-{default['result']}",
            runtime="python3.10",
            disk_size=512,
            code={
                "zip_file": "UEsDBBQACAAIAAAAAAAAAAAAAAAAAAAAAAAIAAAAaW5kZXgucHmEkEFKxEAQRfd9ig9ZTCJOooIwDMwNXLqXnnQlaalUhU5lRj2KZ/FOXkESGR114bJ/P/7jV4b1xRq1hijtFpM1682cuNgPmgysbRulPT0fRxXnMtwrSPyeCdYRokSLnuMLJTTkbUqEvDMbxm1VdcRD6Tk+T1LW2ldB66knsYdA5iNX17ebm6tN2VnPhcswMPmREPuBacb+CiapLarAj9gT6/H97dVlCNScY3mtYvRkxdZlwDKDEnanPWVLdrdkeXEGlFEazVdfPVHaVeHc3N15CUwppwOJXeK7HshAB8NuOU7J6sP4SRXuH/EvbUfMiqMmDqv5M5FNSfAj/wgAAP//UEsHCPl//NYAAQAArwEAAFBLAQIUABQACAAIAAAAAAD5f/zWAAEAAK8BAAAIAAAAAAAAAAAAAAAAAAAAAABpbmRleC5weVBLBQYAAAAAAQABADYAAAA2AQAAAAA=",
            },
            log_config={
                "enable_instance_metrics": True,
                "enable_request_metrics": True,
                "project": default_project.project_name,
                "logstore": default_store.logstore_name,
                "log_begin_rule": "None",
            },
            opts = pulumi.ResourceOptions(depends_on=[wait10_minutes]))
        default_v3_provision_config = alicloud.fc.V3ProvisionConfig("default",
            target=1,
            target_tracking_policies=[
                {
                    "name": "t1",
                    "start_time": "2030-10-10T10:10:10Z",
                    "end_time": "2035-10-10T10:10:10Z",
                    "min_capacity": 0,
                    "max_capacity": 1,
                    "metric_target": 1,
                    "metric_type": "ProvisionedConcurrencyUtilization",
                },
                {
                    "metric_target": 1,
                    "metric_type": "ProvisionedConcurrencyUtilization",
                    "name": "t2",
                    "start_time": "2030-10-10T10:10:10Z",
                    "end_time": "2035-10-10T10:10:10Z",
                    "min_capacity": 0,
                    "max_capacity": 1,
                },
                {
                    "metric_type": "ProvisionedConcurrencyUtilization",
                    "time_zone": "Asia/Shanghai",
                    "name": "t3",
                    "start_time": "2030-10-10T10:10:10",
                    "end_time": "2035-10-10T10:10:10",
                    "min_capacity": 0,
                    "max_capacity": 1,
                    "metric_target": 1,
                },
            ],
            scheduled_actions=[
                {
                    "target": 0,
                    "name": "s1",
                    "start_time": "2030-10-10T10:10:10Z",
                    "end_time": "2035-10-10T10:10:10Z",
                    "schedule_expression": "cron(0 0 4 * * *)",
                },
                {
                    "name": "s2",
                    "start_time": "2030-10-10T10:10:10Z",
                    "end_time": "2035-10-10T10:10:10Z",
                    "schedule_expression": "cron(0 0 6 * * *)",
                    "target": 1,
                },
                {
                    "start_time": "2030-10-10T10:10:10",
                    "end_time": "2035-10-10T10:10:10",
                    "schedule_expression": "cron(0 0 7 * * *)",
                    "target": 0,
                    "time_zone": "Asia/Shanghai",
                    "name": "s3",
                },
            ],
            qualifier="LATEST",
            always_allocate_gpu=True,
            function_name=function.function_name,
            always_allocate_cpu=True)
        ```

        ## Import

        FCV3 Provision Config can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:fc/v3ProvisionConfig:V3ProvisionConfig example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] always_allocate_cpu: Whether the CPU is always allocated. The default value is true.
        :param pulumi.Input[bool] always_allocate_gpu: Whether to always assign GPU to function instance
        :param pulumi.Input[str] function_name: The name of the function. If this parameter is not specified, the provisioned configurations of all functions are listed.
        :param pulumi.Input[str] qualifier: The function alias or LATEST.
        :param pulumi.Input[Sequence[pulumi.Input[Union['V3ProvisionConfigScheduledActionArgs', 'V3ProvisionConfigScheduledActionArgsDict']]]] scheduled_actions: Timing policy configuration See `scheduled_actions` below.
        :param pulumi.Input[int] target: Number of reserved target resources. The value range is [0,10000].
        :param pulumi.Input[Sequence[pulumi.Input[Union['V3ProvisionConfigTargetTrackingPolicyArgs', 'V3ProvisionConfigTargetTrackingPolicyArgsDict']]]] target_tracking_policies: Metric tracking scaling policy configuration See `target_tracking_policies` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: V3ProvisionConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a FCV3 Provision Config resource.

        Function Reservation Configuration.

        For information about FCV3 Provision Config and how to use it, see [What is Provision Config](https://www.alibabacloud.com/help/en/functioncompute/fc-3-0/developer-reference/api-fc-2023-03-30-putprovisionconfig).

        > **NOTE:** Available since v1.230.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random
        import pulumi_time as time

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_project = alicloud.log.Project("default",
            project_name=f"{name}-{default['result']}",
            description=name)
        default_store = alicloud.log.Store("default",
            project_name=default_project.name,
            logstore_name=f"{name}-{default['result']}",
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        wait10_minutes = time.index.Sleep("wait_10_minutes", create_duration=10m,
        opts = pulumi.ResourceOptions(depends_on=[default_store]))
        function = alicloud.fc.V3Function("function",
            memory_size=512,
            cpu=0.5,
            handler="index.handler",
            function_name=f"{name}-{default['result']}",
            runtime="python3.10",
            disk_size=512,
            code={
                "zip_file": "UEsDBBQACAAIAAAAAAAAAAAAAAAAAAAAAAAIAAAAaW5kZXgucHmEkEFKxEAQRfd9ig9ZTCJOooIwDMwNXLqXnnQlaalUhU5lRj2KZ/FOXkESGR114bJ/P/7jV4b1xRq1hijtFpM1682cuNgPmgysbRulPT0fRxXnMtwrSPyeCdYRokSLnuMLJTTkbUqEvDMbxm1VdcRD6Tk+T1LW2ldB66knsYdA5iNX17ebm6tN2VnPhcswMPmREPuBacb+CiapLarAj9gT6/H97dVlCNScY3mtYvRkxdZlwDKDEnanPWVLdrdkeXEGlFEazVdfPVHaVeHc3N15CUwppwOJXeK7HshAB8NuOU7J6sP4SRXuH/EvbUfMiqMmDqv5M5FNSfAj/wgAAP//UEsHCPl//NYAAQAArwEAAFBLAQIUABQACAAIAAAAAAD5f/zWAAEAAK8BAAAIAAAAAAAAAAAAAAAAAAAAAABpbmRleC5weVBLBQYAAAAAAQABADYAAAA2AQAAAAA=",
            },
            log_config={
                "enable_instance_metrics": True,
                "enable_request_metrics": True,
                "project": default_project.project_name,
                "logstore": default_store.logstore_name,
                "log_begin_rule": "None",
            },
            opts = pulumi.ResourceOptions(depends_on=[wait10_minutes]))
        default_v3_provision_config = alicloud.fc.V3ProvisionConfig("default",
            target=1,
            target_tracking_policies=[
                {
                    "name": "t1",
                    "start_time": "2030-10-10T10:10:10Z",
                    "end_time": "2035-10-10T10:10:10Z",
                    "min_capacity": 0,
                    "max_capacity": 1,
                    "metric_target": 1,
                    "metric_type": "ProvisionedConcurrencyUtilization",
                },
                {
                    "metric_target": 1,
                    "metric_type": "ProvisionedConcurrencyUtilization",
                    "name": "t2",
                    "start_time": "2030-10-10T10:10:10Z",
                    "end_time": "2035-10-10T10:10:10Z",
                    "min_capacity": 0,
                    "max_capacity": 1,
                },
                {
                    "metric_type": "ProvisionedConcurrencyUtilization",
                    "time_zone": "Asia/Shanghai",
                    "name": "t3",
                    "start_time": "2030-10-10T10:10:10",
                    "end_time": "2035-10-10T10:10:10",
                    "min_capacity": 0,
                    "max_capacity": 1,
                    "metric_target": 1,
                },
            ],
            scheduled_actions=[
                {
                    "target": 0,
                    "name": "s1",
                    "start_time": "2030-10-10T10:10:10Z",
                    "end_time": "2035-10-10T10:10:10Z",
                    "schedule_expression": "cron(0 0 4 * * *)",
                },
                {
                    "name": "s2",
                    "start_time": "2030-10-10T10:10:10Z",
                    "end_time": "2035-10-10T10:10:10Z",
                    "schedule_expression": "cron(0 0 6 * * *)",
                    "target": 1,
                },
                {
                    "start_time": "2030-10-10T10:10:10",
                    "end_time": "2035-10-10T10:10:10",
                    "schedule_expression": "cron(0 0 7 * * *)",
                    "target": 0,
                    "time_zone": "Asia/Shanghai",
                    "name": "s3",
                },
            ],
            qualifier="LATEST",
            always_allocate_gpu=True,
            function_name=function.function_name,
            always_allocate_cpu=True)
        ```

        ## Import

        FCV3 Provision Config can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:fc/v3ProvisionConfig:V3ProvisionConfig example <id>
        ```

        :param str resource_name: The name of the resource.
        :param V3ProvisionConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(V3ProvisionConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 always_allocate_cpu: Optional[pulumi.Input[bool]] = None,
                 always_allocate_gpu: Optional[pulumi.Input[bool]] = None,
                 function_name: Optional[pulumi.Input[str]] = None,
                 qualifier: Optional[pulumi.Input[str]] = None,
                 scheduled_actions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['V3ProvisionConfigScheduledActionArgs', 'V3ProvisionConfigScheduledActionArgsDict']]]]] = None,
                 target: Optional[pulumi.Input[int]] = None,
                 target_tracking_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['V3ProvisionConfigTargetTrackingPolicyArgs', 'V3ProvisionConfigTargetTrackingPolicyArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = V3ProvisionConfigArgs.__new__(V3ProvisionConfigArgs)

            __props__.__dict__["always_allocate_cpu"] = always_allocate_cpu
            __props__.__dict__["always_allocate_gpu"] = always_allocate_gpu
            if function_name is None and not opts.urn:
                raise TypeError("Missing required property 'function_name'")
            __props__.__dict__["function_name"] = function_name
            __props__.__dict__["qualifier"] = qualifier
            __props__.__dict__["scheduled_actions"] = scheduled_actions
            __props__.__dict__["target"] = target
            __props__.__dict__["target_tracking_policies"] = target_tracking_policies
            __props__.__dict__["current"] = None
            __props__.__dict__["current_error"] = None
            __props__.__dict__["function_arn"] = None
        super(V3ProvisionConfig, __self__).__init__(
            'alicloud:fc/v3ProvisionConfig:V3ProvisionConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            always_allocate_cpu: Optional[pulumi.Input[bool]] = None,
            always_allocate_gpu: Optional[pulumi.Input[bool]] = None,
            current: Optional[pulumi.Input[int]] = None,
            current_error: Optional[pulumi.Input[str]] = None,
            function_arn: Optional[pulumi.Input[str]] = None,
            function_name: Optional[pulumi.Input[str]] = None,
            qualifier: Optional[pulumi.Input[str]] = None,
            scheduled_actions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['V3ProvisionConfigScheduledActionArgs', 'V3ProvisionConfigScheduledActionArgsDict']]]]] = None,
            target: Optional[pulumi.Input[int]] = None,
            target_tracking_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['V3ProvisionConfigTargetTrackingPolicyArgs', 'V3ProvisionConfigTargetTrackingPolicyArgsDict']]]]] = None) -> 'V3ProvisionConfig':
        """
        Get an existing V3ProvisionConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] always_allocate_cpu: Whether the CPU is always allocated. The default value is true.
        :param pulumi.Input[bool] always_allocate_gpu: Whether to always assign GPU to function instance
        :param pulumi.Input[int] current: (Available since v1.234.0) Number of actual resources
        :param pulumi.Input[str] current_error: (Available since v1.234.0) Error message when a Reserved Instance creation fails
        :param pulumi.Input[str] function_arn: (Available since v1.234.0) Resource Description of the function
        :param pulumi.Input[str] function_name: The name of the function. If this parameter is not specified, the provisioned configurations of all functions are listed.
        :param pulumi.Input[str] qualifier: The function alias or LATEST.
        :param pulumi.Input[Sequence[pulumi.Input[Union['V3ProvisionConfigScheduledActionArgs', 'V3ProvisionConfigScheduledActionArgsDict']]]] scheduled_actions: Timing policy configuration See `scheduled_actions` below.
        :param pulumi.Input[int] target: Number of reserved target resources. The value range is [0,10000].
        :param pulumi.Input[Sequence[pulumi.Input[Union['V3ProvisionConfigTargetTrackingPolicyArgs', 'V3ProvisionConfigTargetTrackingPolicyArgsDict']]]] target_tracking_policies: Metric tracking scaling policy configuration See `target_tracking_policies` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _V3ProvisionConfigState.__new__(_V3ProvisionConfigState)

        __props__.__dict__["always_allocate_cpu"] = always_allocate_cpu
        __props__.__dict__["always_allocate_gpu"] = always_allocate_gpu
        __props__.__dict__["current"] = current
        __props__.__dict__["current_error"] = current_error
        __props__.__dict__["function_arn"] = function_arn
        __props__.__dict__["function_name"] = function_name
        __props__.__dict__["qualifier"] = qualifier
        __props__.__dict__["scheduled_actions"] = scheduled_actions
        __props__.__dict__["target"] = target
        __props__.__dict__["target_tracking_policies"] = target_tracking_policies
        return V3ProvisionConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="alwaysAllocateCpu")
    def always_allocate_cpu(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the CPU is always allocated. The default value is true.
        """
        return pulumi.get(self, "always_allocate_cpu")

    @property
    @pulumi.getter(name="alwaysAllocateGpu")
    def always_allocate_gpu(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to always assign GPU to function instance
        """
        return pulumi.get(self, "always_allocate_gpu")

    @property
    @pulumi.getter
    def current(self) -> pulumi.Output[int]:
        """
        (Available since v1.234.0) Number of actual resources
        """
        return pulumi.get(self, "current")

    @property
    @pulumi.getter(name="currentError")
    def current_error(self) -> pulumi.Output[str]:
        """
        (Available since v1.234.0) Error message when a Reserved Instance creation fails
        """
        return pulumi.get(self, "current_error")

    @property
    @pulumi.getter(name="functionArn")
    def function_arn(self) -> pulumi.Output[str]:
        """
        (Available since v1.234.0) Resource Description of the function
        """
        return pulumi.get(self, "function_arn")

    @property
    @pulumi.getter(name="functionName")
    def function_name(self) -> pulumi.Output[str]:
        """
        The name of the function. If this parameter is not specified, the provisioned configurations of all functions are listed.
        """
        return pulumi.get(self, "function_name")

    @property
    @pulumi.getter
    def qualifier(self) -> pulumi.Output[Optional[str]]:
        """
        The function alias or LATEST.
        """
        return pulumi.get(self, "qualifier")

    @property
    @pulumi.getter(name="scheduledActions")
    def scheduled_actions(self) -> pulumi.Output[Optional[Sequence['outputs.V3ProvisionConfigScheduledAction']]]:
        """
        Timing policy configuration See `scheduled_actions` below.
        """
        return pulumi.get(self, "scheduled_actions")

    @property
    @pulumi.getter
    def target(self) -> pulumi.Output[Optional[int]]:
        """
        Number of reserved target resources. The value range is [0,10000].
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter(name="targetTrackingPolicies")
    def target_tracking_policies(self) -> pulumi.Output[Optional[Sequence['outputs.V3ProvisionConfigTargetTrackingPolicy']]]:
        """
        Metric tracking scaling policy configuration See `target_tracking_policies` below.
        """
        return pulumi.get(self, "target_tracking_policies")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSiteMonitorsResult',
    'AwaitableGetSiteMonitorsResult',
    'get_site_monitors',
    'get_site_monitors_output',
]

@pulumi.output_type
class GetSiteMonitorsResult:
    """
    A collection of values returned by getSiteMonitors.
    """
    def __init__(__self__, id=None, ids=None, monitors=None, output_file=None, task_id=None, task_type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if monitors and not isinstance(monitors, list):
            raise TypeError("Expected argument 'monitors' to be a list")
        pulumi.set(__self__, "monitors", monitors)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if task_id and not isinstance(task_id, str):
            raise TypeError("Expected argument 'task_id' to be a str")
        pulumi.set(__self__, "task_id", task_id)
        if task_type and not isinstance(task_type, str):
            raise TypeError("Expected argument 'task_type' to be a str")
        pulumi.set(__self__, "task_type", task_type)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Site Monitor IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def monitors(self) -> Sequence['outputs.GetSiteMonitorsMonitorResult']:
        """
        A list of Site Monitor Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "monitors")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="taskId")
    def task_id(self) -> Optional[str]:
        """
        Task Id.
        """
        return pulumi.get(self, "task_id")

    @property
    @pulumi.getter(name="taskType")
    def task_type(self) -> Optional[str]:
        """
        Task Type.
        """
        return pulumi.get(self, "task_type")


class AwaitableGetSiteMonitorsResult(GetSiteMonitorsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSiteMonitorsResult(
            id=self.id,
            ids=self.ids,
            monitors=self.monitors,
            output_file=self.output_file,
            task_id=self.task_id,
            task_type=self.task_type)


def get_site_monitors(ids: Optional[Sequence[str]] = None,
                      output_file: Optional[str] = None,
                      task_id: Optional[str] = None,
                      task_type: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSiteMonitorsResult:
    """
    This data source provides Cloud Monitor Service Site Monitor available to the user.[What is Site Monitor](https://www.alibabacloud.com/help/en/)

    > **NOTE:** Available since v1.224.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "tf_example"
    default_integer = random.index.Integer("default",
        min=10000,
        max=99999)
    default_site_monitor = alicloud.cms.SiteMonitor("default",
        address="http://www.alibabacloud.com",
        task_name=f"terraform-example-{default_integer['result']}",
        task_type="HTTP",
        interval=5,
        isp_cities=[{
            "city": "546",
            "isp": "465",
        }],
        options_json=\"\"\"{
        "http_method": "get",
        "waitTime_after_completion": null,
        "ipv6_task": false,
        "diagnosis_ping": false,
        "diagnosis_mtr": false,
        "assertions": [
            {
                "operator": "lessThan",
                "type": "response_time",
                "target": 1000
            }
        ],
        "time_out": 30000
    }
    \"\"\")
    default = alicloud.cms.get_site_monitors_output(ids=[default_site_monitor.id],
        task_type="HTTP")
    pulumi.export("alicloudCmsSiteMonitorExampleId", default.monitors[0].task_id)
    ```


    :param Sequence[str] ids: A list of Site Monitor IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str task_id: Task ID.
    :param str task_type: Task Type.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['taskId'] = task_id
    __args__['taskType'] = task_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cms/getSiteMonitors:getSiteMonitors', __args__, opts=opts, typ=GetSiteMonitorsResult).value

    return AwaitableGetSiteMonitorsResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        monitors=pulumi.get(__ret__, 'monitors'),
        output_file=pulumi.get(__ret__, 'output_file'),
        task_id=pulumi.get(__ret__, 'task_id'),
        task_type=pulumi.get(__ret__, 'task_type'))
def get_site_monitors_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                             output_file: Optional[pulumi.Input[Optional[str]]] = None,
                             task_id: Optional[pulumi.Input[Optional[str]]] = None,
                             task_type: Optional[pulumi.Input[Optional[str]]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSiteMonitorsResult]:
    """
    This data source provides Cloud Monitor Service Site Monitor available to the user.[What is Site Monitor](https://www.alibabacloud.com/help/en/)

    > **NOTE:** Available since v1.224.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "tf_example"
    default_integer = random.index.Integer("default",
        min=10000,
        max=99999)
    default_site_monitor = alicloud.cms.SiteMonitor("default",
        address="http://www.alibabacloud.com",
        task_name=f"terraform-example-{default_integer['result']}",
        task_type="HTTP",
        interval=5,
        isp_cities=[{
            "city": "546",
            "isp": "465",
        }],
        options_json=\"\"\"{
        "http_method": "get",
        "waitTime_after_completion": null,
        "ipv6_task": false,
        "diagnosis_ping": false,
        "diagnosis_mtr": false,
        "assertions": [
            {
                "operator": "lessThan",
                "type": "response_time",
                "target": 1000
            }
        ],
        "time_out": 30000
    }
    \"\"\")
    default = alicloud.cms.get_site_monitors_output(ids=[default_site_monitor.id],
        task_type="HTTP")
    pulumi.export("alicloudCmsSiteMonitorExampleId", default.monitors[0].task_id)
    ```


    :param Sequence[str] ids: A list of Site Monitor IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str task_id: Task ID.
    :param str task_type: Task Type.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['taskId'] = task_id
    __args__['taskType'] = task_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cms/getSiteMonitors:getSiteMonitors', __args__, opts=opts, typ=GetSiteMonitorsResult)
    return __ret__.apply(lambda __response__: GetSiteMonitorsResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        monitors=pulumi.get(__response__, 'monitors'),
        output_file=pulumi.get(__response__, 'output_file'),
        task_id=pulumi.get(__response__, 'task_id'),
        task_type=pulumi.get(__response__, 'task_type')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstancesResult',
    'AwaitableGetInstancesResult',
    'get_instances',
    'get_instances_output',
]

@pulumi.output_type
class GetInstancesResult:
    """
    A collection of values returned by getInstances.
    """
    def __init__(__self__, id=None, ids=None, instance_type=None, instances=None, name_regex=None, names=None, output_file=None, status=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[str]:
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetInstancesInstanceResult']:
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


class AwaitableGetInstancesResult(GetInstancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstancesResult(
            id=self.id,
            ids=self.ids,
            instance_type=self.instance_type,
            instances=self.instances,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            status=self.status)


def get_instances(ids: Optional[Sequence[str]] = None,
                  instance_type: Optional[str] = None,
                  name_regex: Optional[str] = None,
                  output_file: Optional[str] = None,
                  status: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstancesResult:
    """
    This data source provides the Eais Instances of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.137.0+.


    :param Sequence[str] ids: A list of Instance IDs.
    :param str instance_type: EAIS instance type. Valid values: `eais.ei-a6.4xlarge`, `eais.ei-a6.2xlarge`, `eais.ei-a6.xlarge`, `eais.ei-a6.large`, `eais.ei-a6.medium`.
    :param str name_regex: A regex string to filter results by Instance name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the resource. Valid values: `Attaching`, `Available`, `Detaching`, `InUse`, `Starting`, `Unavailable`.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['instanceType'] = instance_type
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:eais/getInstances:getInstances', __args__, opts=opts, typ=GetInstancesResult).value

    return AwaitableGetInstancesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        instances=pulumi.get(__ret__, 'instances'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'))
def get_instances_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                         instance_type: Optional[pulumi.Input[Optional[str]]] = None,
                         name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                         output_file: Optional[pulumi.Input[Optional[str]]] = None,
                         status: Optional[pulumi.Input[Optional[str]]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstancesResult]:
    """
    This data source provides the Eais Instances of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.137.0+.


    :param Sequence[str] ids: A list of Instance IDs.
    :param str instance_type: EAIS instance type. Valid values: `eais.ei-a6.4xlarge`, `eais.ei-a6.2xlarge`, `eais.ei-a6.xlarge`, `eais.ei-a6.large`, `eais.ei-a6.medium`.
    :param str name_regex: A regex string to filter results by Instance name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the resource. Valid values: `Attaching`, `Available`, `Detaching`, `InUse`, `Starting`, `Unavailable`.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['instanceType'] = instance_type
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:eais/getInstances:getInstances', __args__, opts=opts, typ=GetInstancesResult)
    return __ret__.apply(lambda __response__: GetInstancesResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        instance_type=pulumi.get(__response__, 'instance_type'),
        instances=pulumi.get(__response__, 'instances'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetVbrPconnAssociationsResult',
    'AwaitableGetVbrPconnAssociationsResult',
    'get_vbr_pconn_associations',
    'get_vbr_pconn_associations_output',
]

@pulumi.output_type
class GetVbrPconnAssociationsResult:
    """
    A collection of values returned by getVbrPconnAssociations.
    """
    def __init__(__self__, associations=None, id=None, ids=None, output_file=None, page_number=None, page_size=None, vbr_id=None):
        if associations and not isinstance(associations, list):
            raise TypeError("Expected argument 'associations' to be a list")
        pulumi.set(__self__, "associations", associations)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if vbr_id and not isinstance(vbr_id, str):
            raise TypeError("Expected argument 'vbr_id' to be a str")
        pulumi.set(__self__, "vbr_id", vbr_id)

    @property
    @pulumi.getter
    def associations(self) -> Sequence['outputs.GetVbrPconnAssociationsAssociationResult']:
        """
        A list of Vbr Pconn Association Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "associations")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="vbrId")
    def vbr_id(self) -> Optional[str]:
        """
        The ID of the VBR instance.
        """
        return pulumi.get(self, "vbr_id")


class AwaitableGetVbrPconnAssociationsResult(GetVbrPconnAssociationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVbrPconnAssociationsResult(
            associations=self.associations,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            vbr_id=self.vbr_id)


def get_vbr_pconn_associations(ids: Optional[Sequence[str]] = None,
                               output_file: Optional[str] = None,
                               page_number: Optional[int] = None,
                               page_size: Optional[int] = None,
                               vbr_id: Optional[str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVbrPconnAssociationsResult:
    """
    This data source provides Express Connect Vbr Pconn Association available to the user.

    > **NOTE:** Available in 1.196.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.expressconnect.get_vbr_pconn_associations(ids=["example_id"],
        vbr_id=default_alicloud_express_connect_vbr_pconn_association["vbrId"])
    pulumi.export("alicloudExpressConnectVbrPconnAssociationExampleId", default.associations[0].id)
    ```


    :param Sequence[str] ids: A list of Vbr Pconn Association IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str vbr_id: The ID of the VBR instance.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['vbrId'] = vbr_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:expressconnect/getVbrPconnAssociations:getVbrPconnAssociations', __args__, opts=opts, typ=GetVbrPconnAssociationsResult).value

    return AwaitableGetVbrPconnAssociationsResult(
        associations=pulumi.get(__ret__, 'associations'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        vbr_id=pulumi.get(__ret__, 'vbr_id'))
def get_vbr_pconn_associations_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                      output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                      page_number: Optional[pulumi.Input[Optional[int]]] = None,
                                      page_size: Optional[pulumi.Input[Optional[int]]] = None,
                                      vbr_id: Optional[pulumi.Input[Optional[str]]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVbrPconnAssociationsResult]:
    """
    This data source provides Express Connect Vbr Pconn Association available to the user.

    > **NOTE:** Available in 1.196.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.expressconnect.get_vbr_pconn_associations(ids=["example_id"],
        vbr_id=default_alicloud_express_connect_vbr_pconn_association["vbrId"])
    pulumi.export("alicloudExpressConnectVbrPconnAssociationExampleId", default.associations[0].id)
    ```


    :param Sequence[str] ids: A list of Vbr Pconn Association IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str vbr_id: The ID of the VBR instance.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['vbrId'] = vbr_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:expressconnect/getVbrPconnAssociations:getVbrPconnAssociations', __args__, opts=opts, typ=GetVbrPconnAssociationsResult)
    return __ret__.apply(lambda __response__: GetVbrPconnAssociationsResult(
        associations=pulumi.get(__response__, 'associations'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        vbr_id=pulumi.get(__response__, 'vbr_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AccessPointArgs', 'AccessPoint']

@pulumi.input_type
class AccessPointArgs:
    def __init__(__self__, *,
                 access_group: pulumi.Input[str],
                 file_system_id: pulumi.Input[str],
                 vpc_id: pulumi.Input[str],
                 vswitch_id: pulumi.Input[str],
                 access_point_name: Optional[pulumi.Input[str]] = None,
                 enabled_ram: Optional[pulumi.Input[bool]] = None,
                 posix_user: Optional[pulumi.Input['AccessPointPosixUserArgs']] = None,
                 root_path: Optional[pulumi.Input[str]] = None,
                 root_path_permission: Optional[pulumi.Input['AccessPointRootPathPermissionArgs']] = None):
        """
        The set of arguments for constructing a AccessPoint resource.
        :param pulumi.Input[str] access_group: The permission group name.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        :param pulumi.Input[str] vswitch_id: The vSwitch ID.
        :param pulumi.Input[str] access_point_name: The Access Point Name.
        :param pulumi.Input[bool] enabled_ram: Whether to enable the RAM policy.
        :param pulumi.Input['AccessPointPosixUserArgs'] posix_user: The Posix user. See `posix_user` below.
        :param pulumi.Input[str] root_path: The root directory.
        :param pulumi.Input['AccessPointRootPathPermissionArgs'] root_path_permission: Root permissions. See `root_path_permission` below.
        """
        pulumi.set(__self__, "access_group", access_group)
        pulumi.set(__self__, "file_system_id", file_system_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        if access_point_name is not None:
            pulumi.set(__self__, "access_point_name", access_point_name)
        if enabled_ram is not None:
            pulumi.set(__self__, "enabled_ram", enabled_ram)
        if posix_user is not None:
            pulumi.set(__self__, "posix_user", posix_user)
        if root_path is not None:
            pulumi.set(__self__, "root_path", root_path)
        if root_path_permission is not None:
            pulumi.set(__self__, "root_path_permission", root_path_permission)

    @property
    @pulumi.getter(name="accessGroup")
    def access_group(self) -> pulumi.Input[str]:
        """
        The permission group name.
        """
        return pulumi.get(self, "access_group")

    @access_group.setter
    def access_group(self, value: pulumi.Input[str]):
        pulumi.set(self, "access_group", value)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Input[str]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[str]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="accessPointName")
    def access_point_name(self) -> Optional[pulumi.Input[str]]:
        """
        The Access Point Name.
        """
        return pulumi.get(self, "access_point_name")

    @access_point_name.setter
    def access_point_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_point_name", value)

    @property
    @pulumi.getter(name="enabledRam")
    def enabled_ram(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable the RAM policy.
        """
        return pulumi.get(self, "enabled_ram")

    @enabled_ram.setter
    def enabled_ram(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled_ram", value)

    @property
    @pulumi.getter(name="posixUser")
    def posix_user(self) -> Optional[pulumi.Input['AccessPointPosixUserArgs']]:
        """
        The Posix user. See `posix_user` below.
        """
        return pulumi.get(self, "posix_user")

    @posix_user.setter
    def posix_user(self, value: Optional[pulumi.Input['AccessPointPosixUserArgs']]):
        pulumi.set(self, "posix_user", value)

    @property
    @pulumi.getter(name="rootPath")
    def root_path(self) -> Optional[pulumi.Input[str]]:
        """
        The root directory.
        """
        return pulumi.get(self, "root_path")

    @root_path.setter
    def root_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "root_path", value)

    @property
    @pulumi.getter(name="rootPathPermission")
    def root_path_permission(self) -> Optional[pulumi.Input['AccessPointRootPathPermissionArgs']]:
        """
        Root permissions. See `root_path_permission` below.
        """
        return pulumi.get(self, "root_path_permission")

    @root_path_permission.setter
    def root_path_permission(self, value: Optional[pulumi.Input['AccessPointRootPathPermissionArgs']]):
        pulumi.set(self, "root_path_permission", value)


@pulumi.input_type
class _AccessPointState:
    def __init__(__self__, *,
                 access_group: Optional[pulumi.Input[str]] = None,
                 access_point_id: Optional[pulumi.Input[str]] = None,
                 access_point_name: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 enabled_ram: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 posix_user: Optional[pulumi.Input['AccessPointPosixUserArgs']] = None,
                 root_path: Optional[pulumi.Input[str]] = None,
                 root_path_permission: Optional[pulumi.Input['AccessPointRootPathPermissionArgs']] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AccessPoint resources.
        :param pulumi.Input[str] access_group: The permission group name.
        :param pulumi.Input[str] access_point_id: Access point ID.
        :param pulumi.Input[str] access_point_name: The Access Point Name.
        :param pulumi.Input[str] create_time: Creation time.
        :param pulumi.Input[bool] enabled_ram: Whether to enable the RAM policy.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input['AccessPointPosixUserArgs'] posix_user: The Posix user. See `posix_user` below.
        :param pulumi.Input[str] root_path: The root directory.
        :param pulumi.Input['AccessPointRootPathPermissionArgs'] root_path_permission: Root permissions. See `root_path_permission` below.
        :param pulumi.Input[str] status: Current access point state.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        :param pulumi.Input[str] vswitch_id: The vSwitch ID.
        """
        if access_group is not None:
            pulumi.set(__self__, "access_group", access_group)
        if access_point_id is not None:
            pulumi.set(__self__, "access_point_id", access_point_id)
        if access_point_name is not None:
            pulumi.set(__self__, "access_point_name", access_point_name)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if enabled_ram is not None:
            pulumi.set(__self__, "enabled_ram", enabled_ram)
        if file_system_id is not None:
            pulumi.set(__self__, "file_system_id", file_system_id)
        if posix_user is not None:
            pulumi.set(__self__, "posix_user", posix_user)
        if root_path is not None:
            pulumi.set(__self__, "root_path", root_path)
        if root_path_permission is not None:
            pulumi.set(__self__, "root_path_permission", root_path_permission)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="accessGroup")
    def access_group(self) -> Optional[pulumi.Input[str]]:
        """
        The permission group name.
        """
        return pulumi.get(self, "access_group")

    @access_group.setter
    def access_group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_group", value)

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> Optional[pulumi.Input[str]]:
        """
        Access point ID.
        """
        return pulumi.get(self, "access_point_id")

    @access_point_id.setter
    def access_point_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_point_id", value)

    @property
    @pulumi.getter(name="accessPointName")
    def access_point_name(self) -> Optional[pulumi.Input[str]]:
        """
        The Access Point Name.
        """
        return pulumi.get(self, "access_point_name")

    @access_point_name.setter
    def access_point_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_point_name", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="enabledRam")
    def enabled_ram(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable the RAM policy.
        """
        return pulumi.get(self, "enabled_ram")

    @enabled_ram.setter
    def enabled_ram(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled_ram", value)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="posixUser")
    def posix_user(self) -> Optional[pulumi.Input['AccessPointPosixUserArgs']]:
        """
        The Posix user. See `posix_user` below.
        """
        return pulumi.get(self, "posix_user")

    @posix_user.setter
    def posix_user(self, value: Optional[pulumi.Input['AccessPointPosixUserArgs']]):
        pulumi.set(self, "posix_user", value)

    @property
    @pulumi.getter(name="rootPath")
    def root_path(self) -> Optional[pulumi.Input[str]]:
        """
        The root directory.
        """
        return pulumi.get(self, "root_path")

    @root_path.setter
    def root_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "root_path", value)

    @property
    @pulumi.getter(name="rootPathPermission")
    def root_path_permission(self) -> Optional[pulumi.Input['AccessPointRootPathPermissionArgs']]:
        """
        Root permissions. See `root_path_permission` below.
        """
        return pulumi.get(self, "root_path_permission")

    @root_path_permission.setter
    def root_path_permission(self, value: Optional[pulumi.Input['AccessPointRootPathPermissionArgs']]):
        pulumi.set(self, "root_path_permission", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Current access point state.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)


class AccessPoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_group: Optional[pulumi.Input[str]] = None,
                 access_point_name: Optional[pulumi.Input[str]] = None,
                 enabled_ram: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 posix_user: Optional[pulumi.Input[Union['AccessPointPosixUserArgs', 'AccessPointPosixUserArgsDict']]] = None,
                 root_path: Optional[pulumi.Input[str]] = None,
                 root_path_permission: Optional[pulumi.Input[Union['AccessPointRootPathPermissionArgs', 'AccessPointRootPathPermissionArgsDict']]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a NAS Access Point resource.

        For information about NAS Access Point and how to use it, see [What is Access Point](https://www.alibabacloud.com/help/zh/nas/developer-reference/api-nas-2017-06-26-createaccesspoint).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-hangzhou"
        azone = config.get("azone")
        if azone is None:
            azone = "cn-hangzhou-g"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        defaultky_vc70 = alicloud.vpc.Network("defaultkyVC70",
            cidr_block="172.16.0.0/12",
            description="接入点测试noRootDirectory")
        defaulto_za_pm_o = alicloud.vpc.Switch("defaultoZAPmO",
            vpc_id=defaultky_vc70.id,
            zone_id=default.zones[0].id,
            cidr_block="172.16.0.0/24")
        default_bbc7ev = alicloud.nas.AccessGroup("defaultBbc7ev",
            access_group_type="Vpc",
            access_group_name=name,
            file_system_type="standard")
        default_vt_up_dh = alicloud.nas.FileSystem("defaultVtUpDh",
            storage_type="Performance",
            zone_id=azone,
            encrypt_type=0,
            protocol_type="NFS",
            file_system_type="standard",
            description="AccessPointnoRootDirectory")
        default_access_point = alicloud.nas.AccessPoint("default",
            vpc_id=defaultky_vc70.id,
            access_group=default_bbc7ev.access_group_name,
            vswitch_id=defaulto_za_pm_o.id,
            file_system_id=default_vt_up_dh.id,
            access_point_name=name,
            posix_user={
                "posix_group_id": 123,
                "posix_user_id": 123,
            },
            root_path_permission={
                "owner_group_id": 1,
                "owner_user_id": 1,
                "permission": "0777",
            })
        ```

        ## Import

        NAS Access Point can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:nas/accessPoint:AccessPoint example <file_system_id>:<access_point_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_group: The permission group name.
        :param pulumi.Input[str] access_point_name: The Access Point Name.
        :param pulumi.Input[bool] enabled_ram: Whether to enable the RAM policy.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[Union['AccessPointPosixUserArgs', 'AccessPointPosixUserArgsDict']] posix_user: The Posix user. See `posix_user` below.
        :param pulumi.Input[str] root_path: The root directory.
        :param pulumi.Input[Union['AccessPointRootPathPermissionArgs', 'AccessPointRootPathPermissionArgsDict']] root_path_permission: Root permissions. See `root_path_permission` below.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        :param pulumi.Input[str] vswitch_id: The vSwitch ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccessPointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a NAS Access Point resource.

        For information about NAS Access Point and how to use it, see [What is Access Point](https://www.alibabacloud.com/help/zh/nas/developer-reference/api-nas-2017-06-26-createaccesspoint).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-hangzhou"
        azone = config.get("azone")
        if azone is None:
            azone = "cn-hangzhou-g"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        defaultky_vc70 = alicloud.vpc.Network("defaultkyVC70",
            cidr_block="172.16.0.0/12",
            description="接入点测试noRootDirectory")
        defaulto_za_pm_o = alicloud.vpc.Switch("defaultoZAPmO",
            vpc_id=defaultky_vc70.id,
            zone_id=default.zones[0].id,
            cidr_block="172.16.0.0/24")
        default_bbc7ev = alicloud.nas.AccessGroup("defaultBbc7ev",
            access_group_type="Vpc",
            access_group_name=name,
            file_system_type="standard")
        default_vt_up_dh = alicloud.nas.FileSystem("defaultVtUpDh",
            storage_type="Performance",
            zone_id=azone,
            encrypt_type=0,
            protocol_type="NFS",
            file_system_type="standard",
            description="AccessPointnoRootDirectory")
        default_access_point = alicloud.nas.AccessPoint("default",
            vpc_id=defaultky_vc70.id,
            access_group=default_bbc7ev.access_group_name,
            vswitch_id=defaulto_za_pm_o.id,
            file_system_id=default_vt_up_dh.id,
            access_point_name=name,
            posix_user={
                "posix_group_id": 123,
                "posix_user_id": 123,
            },
            root_path_permission={
                "owner_group_id": 1,
                "owner_user_id": 1,
                "permission": "0777",
            })
        ```

        ## Import

        NAS Access Point can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:nas/accessPoint:AccessPoint example <file_system_id>:<access_point_id>
        ```

        :param str resource_name: The name of the resource.
        :param AccessPointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccessPointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_group: Optional[pulumi.Input[str]] = None,
                 access_point_name: Optional[pulumi.Input[str]] = None,
                 enabled_ram: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 posix_user: Optional[pulumi.Input[Union['AccessPointPosixUserArgs', 'AccessPointPosixUserArgsDict']]] = None,
                 root_path: Optional[pulumi.Input[str]] = None,
                 root_path_permission: Optional[pulumi.Input[Union['AccessPointRootPathPermissionArgs', 'AccessPointRootPathPermissionArgsDict']]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccessPointArgs.__new__(AccessPointArgs)

            if access_group is None and not opts.urn:
                raise TypeError("Missing required property 'access_group'")
            __props__.__dict__["access_group"] = access_group
            __props__.__dict__["access_point_name"] = access_point_name
            __props__.__dict__["enabled_ram"] = enabled_ram
            if file_system_id is None and not opts.urn:
                raise TypeError("Missing required property 'file_system_id'")
            __props__.__dict__["file_system_id"] = file_system_id
            __props__.__dict__["posix_user"] = posix_user
            __props__.__dict__["root_path"] = root_path
            __props__.__dict__["root_path_permission"] = root_path_permission
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["access_point_id"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(AccessPoint, __self__).__init__(
            'alicloud:nas/accessPoint:AccessPoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_group: Optional[pulumi.Input[str]] = None,
            access_point_id: Optional[pulumi.Input[str]] = None,
            access_point_name: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            enabled_ram: Optional[pulumi.Input[bool]] = None,
            file_system_id: Optional[pulumi.Input[str]] = None,
            posix_user: Optional[pulumi.Input[Union['AccessPointPosixUserArgs', 'AccessPointPosixUserArgsDict']]] = None,
            root_path: Optional[pulumi.Input[str]] = None,
            root_path_permission: Optional[pulumi.Input[Union['AccessPointRootPathPermissionArgs', 'AccessPointRootPathPermissionArgsDict']]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vswitch_id: Optional[pulumi.Input[str]] = None) -> 'AccessPoint':
        """
        Get an existing AccessPoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_group: The permission group name.
        :param pulumi.Input[str] access_point_id: Access point ID.
        :param pulumi.Input[str] access_point_name: The Access Point Name.
        :param pulumi.Input[str] create_time: Creation time.
        :param pulumi.Input[bool] enabled_ram: Whether to enable the RAM policy.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[Union['AccessPointPosixUserArgs', 'AccessPointPosixUserArgsDict']] posix_user: The Posix user. See `posix_user` below.
        :param pulumi.Input[str] root_path: The root directory.
        :param pulumi.Input[Union['AccessPointRootPathPermissionArgs', 'AccessPointRootPathPermissionArgsDict']] root_path_permission: Root permissions. See `root_path_permission` below.
        :param pulumi.Input[str] status: Current access point state.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        :param pulumi.Input[str] vswitch_id: The vSwitch ID.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccessPointState.__new__(_AccessPointState)

        __props__.__dict__["access_group"] = access_group
        __props__.__dict__["access_point_id"] = access_point_id
        __props__.__dict__["access_point_name"] = access_point_name
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["enabled_ram"] = enabled_ram
        __props__.__dict__["file_system_id"] = file_system_id
        __props__.__dict__["posix_user"] = posix_user
        __props__.__dict__["root_path"] = root_path
        __props__.__dict__["root_path_permission"] = root_path_permission
        __props__.__dict__["status"] = status
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_id"] = vswitch_id
        return AccessPoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessGroup")
    def access_group(self) -> pulumi.Output[str]:
        """
        The permission group name.
        """
        return pulumi.get(self, "access_group")

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> pulumi.Output[str]:
        """
        Access point ID.
        """
        return pulumi.get(self, "access_point_id")

    @property
    @pulumi.getter(name="accessPointName")
    def access_point_name(self) -> pulumi.Output[Optional[str]]:
        """
        The Access Point Name.
        """
        return pulumi.get(self, "access_point_name")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="enabledRam")
    def enabled_ram(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to enable the RAM policy.
        """
        return pulumi.get(self, "enabled_ram")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Output[str]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="posixUser")
    def posix_user(self) -> pulumi.Output['outputs.AccessPointPosixUser']:
        """
        The Posix user. See `posix_user` below.
        """
        return pulumi.get(self, "posix_user")

    @property
    @pulumi.getter(name="rootPath")
    def root_path(self) -> pulumi.Output[str]:
        """
        The root directory.
        """
        return pulumi.get(self, "root_path")

    @property
    @pulumi.getter(name="rootPathPermission")
    def root_path_permission(self) -> pulumi.Output['outputs.AccessPointRootPathPermission']:
        """
        Root permissions. See `root_path_permission` below.
        """
        return pulumi.get(self, "root_path_permission")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Current access point state.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[str]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDdosCooPortsResult',
    'AwaitableGetDdosCooPortsResult',
    'get_ddos_coo_ports',
    'get_ddos_coo_ports_output',
]

@pulumi.output_type
class GetDdosCooPortsResult:
    """
    A collection of values returned by getDdosCooPorts.
    """
    def __init__(__self__, frontend_port=None, frontend_protocol=None, id=None, ids=None, instance_id=None, output_file=None, ports=None):
        if frontend_port and not isinstance(frontend_port, str):
            raise TypeError("Expected argument 'frontend_port' to be a str")
        pulumi.set(__self__, "frontend_port", frontend_port)
        if frontend_protocol and not isinstance(frontend_protocol, str):
            raise TypeError("Expected argument 'frontend_protocol' to be a str")
        pulumi.set(__self__, "frontend_protocol", frontend_protocol)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if ports and not isinstance(ports, list):
            raise TypeError("Expected argument 'ports' to be a list")
        pulumi.set(__self__, "ports", ports)

    @property
    @pulumi.getter(name="frontendPort")
    def frontend_port(self) -> Optional[str]:
        return pulumi.get(self, "frontend_port")

    @property
    @pulumi.getter(name="frontendProtocol")
    def frontend_protocol(self) -> Optional[str]:
        return pulumi.get(self, "frontend_protocol")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def ports(self) -> Sequence['outputs.GetDdosCooPortsPortResult']:
        return pulumi.get(self, "ports")


class AwaitableGetDdosCooPortsResult(GetDdosCooPortsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDdosCooPortsResult(
            frontend_port=self.frontend_port,
            frontend_protocol=self.frontend_protocol,
            id=self.id,
            ids=self.ids,
            instance_id=self.instance_id,
            output_file=self.output_file,
            ports=self.ports)


def get_ddos_coo_ports(frontend_port: Optional[str] = None,
                       frontend_protocol: Optional[str] = None,
                       ids: Optional[Sequence[str]] = None,
                       instance_id: Optional[str] = None,
                       output_file: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDdosCooPortsResult:
    """
    This data source provides the Ddoscoo Ports of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.123.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.ddos.get_ddos_coo_ports(instance_id="ddoscoo-cn-6ja1rl4j****",
        ids=["ddoscoo-cn-6ja1rl4j****:7001:tcp"])
    pulumi.export("firstDdoscooPortId", example.ports[0].id)
    ```


    :param str frontend_port: The forwarding port.
    :param str frontend_protocol: The forwarding protocol. Valid values `tcp` and `udp`.
    :param Sequence[str] ids: A list of Port IDs.
    :param str instance_id: The Ddoscoo instance ID.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['frontendPort'] = frontend_port
    __args__['frontendProtocol'] = frontend_protocol
    __args__['ids'] = ids
    __args__['instanceId'] = instance_id
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ddos/getDdosCooPorts:getDdosCooPorts', __args__, opts=opts, typ=GetDdosCooPortsResult).value

    return AwaitableGetDdosCooPortsResult(
        frontend_port=pulumi.get(__ret__, 'frontend_port'),
        frontend_protocol=pulumi.get(__ret__, 'frontend_protocol'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        output_file=pulumi.get(__ret__, 'output_file'),
        ports=pulumi.get(__ret__, 'ports'))
def get_ddos_coo_ports_output(frontend_port: Optional[pulumi.Input[Optional[str]]] = None,
                              frontend_protocol: Optional[pulumi.Input[Optional[str]]] = None,
                              ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                              instance_id: Optional[pulumi.Input[str]] = None,
                              output_file: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDdosCooPortsResult]:
    """
    This data source provides the Ddoscoo Ports of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.123.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.ddos.get_ddos_coo_ports(instance_id="ddoscoo-cn-6ja1rl4j****",
        ids=["ddoscoo-cn-6ja1rl4j****:7001:tcp"])
    pulumi.export("firstDdoscooPortId", example.ports[0].id)
    ```


    :param str frontend_port: The forwarding port.
    :param str frontend_protocol: The forwarding protocol. Valid values `tcp` and `udp`.
    :param Sequence[str] ids: A list of Port IDs.
    :param str instance_id: The Ddoscoo instance ID.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['frontendPort'] = frontend_port
    __args__['frontendProtocol'] = frontend_protocol
    __args__['ids'] = ids
    __args__['instanceId'] = instance_id
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ddos/getDdosCooPorts:getDdosCooPorts', __args__, opts=opts, typ=GetDdosCooPortsResult)
    return __ret__.apply(lambda __response__: GetDdosCooPortsResult(
        frontend_port=pulumi.get(__response__, 'frontend_port'),
        frontend_protocol=pulumi.get(__response__, 'frontend_protocol'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        output_file=pulumi.get(__response__, 'output_file'),
        ports=pulumi.get(__response__, 'ports')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SwitchArgs', 'Switch']

@pulumi.input_type
class SwitchArgs:
    def __init__(__self__, *,
                 availability_zone: Optional[pulumi.Input[str]] = None,
                 cidr_block: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_ipv6: Optional[pulumi.Input[bool]] = None,
                 ipv6_cidr_block_mask: Optional[pulumi.Input[int]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_name: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Switch resource.
        :param pulumi.Input[str] availability_zone: Field `availability_zone` has been deprecated from provider version 1.119.0. New field `zone_id` instead.
        :param pulumi.Input[str] cidr_block: The IPv4 CIDR block of the VSwitch. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `cidr_block` is required.
        :param pulumi.Input[str] description: The description of VSwitch.
        :param pulumi.Input[bool] enable_ipv6: Whether the IPv6 function is enabled in the switch. Value:
        :param pulumi.Input[int] ipv6_cidr_block_mask: The IPv6 CIDR block of the VSwitch.
        :param pulumi.Input[bool] is_default: Specifies whether to create the default VSwitch. Default value: `false`. Valid values:
        :param pulumi.Input[str] name: Field `name` has been deprecated from provider version 1.119.0. New field `vswitch_name` instead.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tags of VSwitch.
        :param pulumi.Input[str] vpc_id: The VPC ID. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `vpc_id` is required.
        :param pulumi.Input[str] vswitch_name: The name of the VSwitch.
        :param pulumi.Input[str] zone_id: The AZ for the VSwitch. **Note:** Required for a VPC VSwitch.
        """
        if availability_zone is not None:
            warnings.warn("""Field 'availability_zone' has been deprecated from provider version 1.119.0. New field 'zone_id' instead.""", DeprecationWarning)
            pulumi.log.warn("""availability_zone is deprecated: Field 'availability_zone' has been deprecated from provider version 1.119.0. New field 'zone_id' instead.""")
        if availability_zone is not None:
            pulumi.set(__self__, "availability_zone", availability_zone)
        if cidr_block is not None:
            pulumi.set(__self__, "cidr_block", cidr_block)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_ipv6 is not None:
            pulumi.set(__self__, "enable_ipv6", enable_ipv6)
        if ipv6_cidr_block_mask is not None:
            pulumi.set(__self__, "ipv6_cidr_block_mask", ipv6_cidr_block_mask)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if name is not None:
            warnings.warn("""Field 'name' has been deprecated from provider version 1.119.0. New field 'vswitch_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""name is deprecated: Field 'name' has been deprecated from provider version 1.119.0. New field 'vswitch_name' instead.""")
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_name is not None:
            pulumi.set(__self__, "vswitch_name", vswitch_name)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="availabilityZone")
    @_utilities.deprecated("""Field 'availability_zone' has been deprecated from provider version 1.119.0. New field 'zone_id' instead.""")
    def availability_zone(self) -> Optional[pulumi.Input[str]]:
        """
        Field `availability_zone` has been deprecated from provider version 1.119.0. New field `zone_id` instead.
        """
        return pulumi.get(self, "availability_zone")

    @availability_zone.setter
    def availability_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "availability_zone", value)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv4 CIDR block of the VSwitch. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `cidr_block` is required.
        """
        return pulumi.get(self, "cidr_block")

    @cidr_block.setter
    def cidr_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_block", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of VSwitch.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the IPv6 function is enabled in the switch. Value:
        """
        return pulumi.get(self, "enable_ipv6")

    @enable_ipv6.setter
    def enable_ipv6(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_ipv6", value)

    @property
    @pulumi.getter(name="ipv6CidrBlockMask")
    def ipv6_cidr_block_mask(self) -> Optional[pulumi.Input[int]]:
        """
        The IPv6 CIDR block of the VSwitch.
        """
        return pulumi.get(self, "ipv6_cidr_block_mask")

    @ipv6_cidr_block_mask.setter
    def ipv6_cidr_block_mask(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ipv6_cidr_block_mask", value)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to create the default VSwitch. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated from provider version 1.119.0. New field 'vswitch_name' instead.""")
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Field `name` has been deprecated from provider version 1.119.0. New field `vswitch_name` instead.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tags of VSwitch.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The VPC ID. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `vpc_id` is required.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchName")
    def vswitch_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the VSwitch.
        """
        return pulumi.get(self, "vswitch_name")

    @vswitch_name.setter
    def vswitch_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_name", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        The AZ for the VSwitch. **Note:** Required for a VPC VSwitch.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.input_type
class _SwitchState:
    def __init__(__self__, *,
                 availability_zone: Optional[pulumi.Input[str]] = None,
                 cidr_block: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_ipv6: Optional[pulumi.Input[bool]] = None,
                 ipv6_cidr_block: Optional[pulumi.Input[str]] = None,
                 ipv6_cidr_block_mask: Optional[pulumi.Input[int]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_name: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Switch resources.
        :param pulumi.Input[str] availability_zone: Field `availability_zone` has been deprecated from provider version 1.119.0. New field `zone_id` instead.
        :param pulumi.Input[str] cidr_block: The IPv4 CIDR block of the VSwitch. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `cidr_block` is required.
        :param pulumi.Input[str] create_time: The creation time of the VSwitch.
        :param pulumi.Input[str] description: The description of VSwitch.
        :param pulumi.Input[bool] enable_ipv6: Whether the IPv6 function is enabled in the switch. Value:
        :param pulumi.Input[str] ipv6_cidr_block: The IPv6 CIDR block of the VSwitch.
        :param pulumi.Input[int] ipv6_cidr_block_mask: The IPv6 CIDR block of the VSwitch.
        :param pulumi.Input[bool] is_default: Specifies whether to create the default VSwitch. Default value: `false`. Valid values:
        :param pulumi.Input[str] name: Field `name` has been deprecated from provider version 1.119.0. New field `vswitch_name` instead.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tags of VSwitch.
        :param pulumi.Input[str] vpc_id: The VPC ID. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `vpc_id` is required.
        :param pulumi.Input[str] vswitch_name: The name of the VSwitch.
        :param pulumi.Input[str] zone_id: The AZ for the VSwitch. **Note:** Required for a VPC VSwitch.
        """
        if availability_zone is not None:
            warnings.warn("""Field 'availability_zone' has been deprecated from provider version 1.119.0. New field 'zone_id' instead.""", DeprecationWarning)
            pulumi.log.warn("""availability_zone is deprecated: Field 'availability_zone' has been deprecated from provider version 1.119.0. New field 'zone_id' instead.""")
        if availability_zone is not None:
            pulumi.set(__self__, "availability_zone", availability_zone)
        if cidr_block is not None:
            pulumi.set(__self__, "cidr_block", cidr_block)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_ipv6 is not None:
            pulumi.set(__self__, "enable_ipv6", enable_ipv6)
        if ipv6_cidr_block is not None:
            pulumi.set(__self__, "ipv6_cidr_block", ipv6_cidr_block)
        if ipv6_cidr_block_mask is not None:
            pulumi.set(__self__, "ipv6_cidr_block_mask", ipv6_cidr_block_mask)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if name is not None:
            warnings.warn("""Field 'name' has been deprecated from provider version 1.119.0. New field 'vswitch_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""name is deprecated: Field 'name' has been deprecated from provider version 1.119.0. New field 'vswitch_name' instead.""")
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_name is not None:
            pulumi.set(__self__, "vswitch_name", vswitch_name)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="availabilityZone")
    @_utilities.deprecated("""Field 'availability_zone' has been deprecated from provider version 1.119.0. New field 'zone_id' instead.""")
    def availability_zone(self) -> Optional[pulumi.Input[str]]:
        """
        Field `availability_zone` has been deprecated from provider version 1.119.0. New field `zone_id` instead.
        """
        return pulumi.get(self, "availability_zone")

    @availability_zone.setter
    def availability_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "availability_zone", value)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv4 CIDR block of the VSwitch. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `cidr_block` is required.
        """
        return pulumi.get(self, "cidr_block")

    @cidr_block.setter
    def cidr_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_block", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the VSwitch.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of VSwitch.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the IPv6 function is enabled in the switch. Value:
        """
        return pulumi.get(self, "enable_ipv6")

    @enable_ipv6.setter
    def enable_ipv6(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_ipv6", value)

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv6 CIDR block of the VSwitch.
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipv6_cidr_block", value)

    @property
    @pulumi.getter(name="ipv6CidrBlockMask")
    def ipv6_cidr_block_mask(self) -> Optional[pulumi.Input[int]]:
        """
        The IPv6 CIDR block of the VSwitch.
        """
        return pulumi.get(self, "ipv6_cidr_block_mask")

    @ipv6_cidr_block_mask.setter
    def ipv6_cidr_block_mask(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ipv6_cidr_block_mask", value)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to create the default VSwitch. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated from provider version 1.119.0. New field 'vswitch_name' instead.""")
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Field `name` has been deprecated from provider version 1.119.0. New field `vswitch_name` instead.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tags of VSwitch.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The VPC ID. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `vpc_id` is required.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchName")
    def vswitch_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the VSwitch.
        """
        return pulumi.get(self, "vswitch_name")

    @vswitch_name.setter
    def vswitch_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_name", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        The AZ for the VSwitch. **Note:** Required for a VPC VSwitch.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone_id", value)


class Switch(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 availability_zone: Optional[pulumi.Input[str]] = None,
                 cidr_block: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_ipv6: Optional[pulumi.Input[bool]] = None,
                 ipv6_cidr_block_mask: Optional[pulumi.Input[int]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_name: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a VPC Vswitch resource. ## Module Support

        You can use to the existing vpc module  to create a VPC and several VSwitches one-click.

        For information about VPC Vswitch and how to use it, see [What is Vswitch](https://www.alibabacloud.com/help/en/virtual-private-cloud/latest/work-with-vswitches).

        > **NOTE:** Available since v1.0.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        foo = alicloud.get_zones(available_resource_creation="VSwitch")
        foo_network = alicloud.vpc.Network("foo",
            vpc_name="terraform-example",
            cidr_block="172.16.0.0/12")
        foo_switch = alicloud.vpc.Switch("foo",
            vswitch_name="terraform-example",
            cidr_block="172.16.0.0/21",
            vpc_id=foo_network.id,
            zone_id=foo.zones[0].id)
        ```

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        foo = alicloud.get_zones(available_resource_creation="VSwitch")
        vpc = alicloud.vpc.Network("vpc",
            vpc_name="terraform-example",
            cidr_block="172.16.0.0/12")
        cidr_blocks = alicloud.vpc.Ipv4CidrBlock("cidr_blocks",
            vpc_id=vpc.id,
            secondary_cidr_block="192.163.0.0/16")
        island_nat = alicloud.vpc.Switch("island-nat",
            vpc_id=cidr_blocks.vpc_id,
            cidr_block="172.16.0.0/21",
            zone_id=foo.zones[0].id,
            vswitch_name="terraform-example",
            tags={
                "BuiltBy": "example_value",
                "cnm_version": "example_value",
                "Environment": "example_value",
                "ManagedBy": "example_value",
            })
        ```

        Create a switch associated with the additional network segment

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        foo = alicloud.get_zones(available_resource_creation="VSwitch")
        foo_network = alicloud.vpc.Network("foo",
            vpc_name="terraform-example",
            cidr_block="172.16.0.0/12")
        foo_ipv4_cidr_block = alicloud.vpc.Ipv4CidrBlock("foo",
            vpc_id=foo_network.id,
            secondary_cidr_block="192.163.0.0/16")
        foo_switch = alicloud.vpc.Switch("foo",
            vpc_id=foo_ipv4_cidr_block.vpc_id,
            cidr_block="192.163.0.0/24",
            zone_id=foo.zones[0].id)
        ```

        ## Import

        VPC Vswitch can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/switch:Switch example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] availability_zone: Field `availability_zone` has been deprecated from provider version 1.119.0. New field `zone_id` instead.
        :param pulumi.Input[str] cidr_block: The IPv4 CIDR block of the VSwitch. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `cidr_block` is required.
        :param pulumi.Input[str] description: The description of VSwitch.
        :param pulumi.Input[bool] enable_ipv6: Whether the IPv6 function is enabled in the switch. Value:
        :param pulumi.Input[int] ipv6_cidr_block_mask: The IPv6 CIDR block of the VSwitch.
        :param pulumi.Input[bool] is_default: Specifies whether to create the default VSwitch. Default value: `false`. Valid values:
        :param pulumi.Input[str] name: Field `name` has been deprecated from provider version 1.119.0. New field `vswitch_name` instead.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tags of VSwitch.
        :param pulumi.Input[str] vpc_id: The VPC ID. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `vpc_id` is required.
        :param pulumi.Input[str] vswitch_name: The name of the VSwitch.
        :param pulumi.Input[str] zone_id: The AZ for the VSwitch. **Note:** Required for a VPC VSwitch.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SwitchArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a VPC Vswitch resource. ## Module Support

        You can use to the existing vpc module  to create a VPC and several VSwitches one-click.

        For information about VPC Vswitch and how to use it, see [What is Vswitch](https://www.alibabacloud.com/help/en/virtual-private-cloud/latest/work-with-vswitches).

        > **NOTE:** Available since v1.0.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        foo = alicloud.get_zones(available_resource_creation="VSwitch")
        foo_network = alicloud.vpc.Network("foo",
            vpc_name="terraform-example",
            cidr_block="172.16.0.0/12")
        foo_switch = alicloud.vpc.Switch("foo",
            vswitch_name="terraform-example",
            cidr_block="172.16.0.0/21",
            vpc_id=foo_network.id,
            zone_id=foo.zones[0].id)
        ```

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        foo = alicloud.get_zones(available_resource_creation="VSwitch")
        vpc = alicloud.vpc.Network("vpc",
            vpc_name="terraform-example",
            cidr_block="172.16.0.0/12")
        cidr_blocks = alicloud.vpc.Ipv4CidrBlock("cidr_blocks",
            vpc_id=vpc.id,
            secondary_cidr_block="192.163.0.0/16")
        island_nat = alicloud.vpc.Switch("island-nat",
            vpc_id=cidr_blocks.vpc_id,
            cidr_block="172.16.0.0/21",
            zone_id=foo.zones[0].id,
            vswitch_name="terraform-example",
            tags={
                "BuiltBy": "example_value",
                "cnm_version": "example_value",
                "Environment": "example_value",
                "ManagedBy": "example_value",
            })
        ```

        Create a switch associated with the additional network segment

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        foo = alicloud.get_zones(available_resource_creation="VSwitch")
        foo_network = alicloud.vpc.Network("foo",
            vpc_name="terraform-example",
            cidr_block="172.16.0.0/12")
        foo_ipv4_cidr_block = alicloud.vpc.Ipv4CidrBlock("foo",
            vpc_id=foo_network.id,
            secondary_cidr_block="192.163.0.0/16")
        foo_switch = alicloud.vpc.Switch("foo",
            vpc_id=foo_ipv4_cidr_block.vpc_id,
            cidr_block="192.163.0.0/24",
            zone_id=foo.zones[0].id)
        ```

        ## Import

        VPC Vswitch can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/switch:Switch example <id>
        ```

        :param str resource_name: The name of the resource.
        :param SwitchArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SwitchArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 availability_zone: Optional[pulumi.Input[str]] = None,
                 cidr_block: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_ipv6: Optional[pulumi.Input[bool]] = None,
                 ipv6_cidr_block_mask: Optional[pulumi.Input[int]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_name: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SwitchArgs.__new__(SwitchArgs)

            __props__.__dict__["availability_zone"] = availability_zone
            __props__.__dict__["cidr_block"] = cidr_block
            __props__.__dict__["description"] = description
            __props__.__dict__["enable_ipv6"] = enable_ipv6
            __props__.__dict__["ipv6_cidr_block_mask"] = ipv6_cidr_block_mask
            __props__.__dict__["is_default"] = is_default
            __props__.__dict__["name"] = name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["vswitch_name"] = vswitch_name
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["ipv6_cidr_block"] = None
            __props__.__dict__["status"] = None
        super(Switch, __self__).__init__(
            'alicloud:vpc/switch:Switch',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            availability_zone: Optional[pulumi.Input[str]] = None,
            cidr_block: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            enable_ipv6: Optional[pulumi.Input[bool]] = None,
            ipv6_cidr_block: Optional[pulumi.Input[str]] = None,
            ipv6_cidr_block_mask: Optional[pulumi.Input[int]] = None,
            is_default: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vswitch_name: Optional[pulumi.Input[str]] = None,
            zone_id: Optional[pulumi.Input[str]] = None) -> 'Switch':
        """
        Get an existing Switch resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] availability_zone: Field `availability_zone` has been deprecated from provider version 1.119.0. New field `zone_id` instead.
        :param pulumi.Input[str] cidr_block: The IPv4 CIDR block of the VSwitch. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `cidr_block` is required.
        :param pulumi.Input[str] create_time: The creation time of the VSwitch.
        :param pulumi.Input[str] description: The description of VSwitch.
        :param pulumi.Input[bool] enable_ipv6: Whether the IPv6 function is enabled in the switch. Value:
        :param pulumi.Input[str] ipv6_cidr_block: The IPv6 CIDR block of the VSwitch.
        :param pulumi.Input[int] ipv6_cidr_block_mask: The IPv6 CIDR block of the VSwitch.
        :param pulumi.Input[bool] is_default: Specifies whether to create the default VSwitch. Default value: `false`. Valid values:
        :param pulumi.Input[str] name: Field `name` has been deprecated from provider version 1.119.0. New field `vswitch_name` instead.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tags of VSwitch.
        :param pulumi.Input[str] vpc_id: The VPC ID. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `vpc_id` is required.
        :param pulumi.Input[str] vswitch_name: The name of the VSwitch.
        :param pulumi.Input[str] zone_id: The AZ for the VSwitch. **Note:** Required for a VPC VSwitch.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SwitchState.__new__(_SwitchState)

        __props__.__dict__["availability_zone"] = availability_zone
        __props__.__dict__["cidr_block"] = cidr_block
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_ipv6"] = enable_ipv6
        __props__.__dict__["ipv6_cidr_block"] = ipv6_cidr_block
        __props__.__dict__["ipv6_cidr_block_mask"] = ipv6_cidr_block_mask
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["name"] = name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_name"] = vswitch_name
        __props__.__dict__["zone_id"] = zone_id
        return Switch(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="availabilityZone")
    @_utilities.deprecated("""Field 'availability_zone' has been deprecated from provider version 1.119.0. New field 'zone_id' instead.""")
    def availability_zone(self) -> pulumi.Output[str]:
        """
        Field `availability_zone` has been deprecated from provider version 1.119.0. New field `zone_id` instead.
        """
        return pulumi.get(self, "availability_zone")

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> pulumi.Output[str]:
        """
        The IPv4 CIDR block of the VSwitch. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `cidr_block` is required.
        """
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the VSwitch.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of VSwitch.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the IPv6 function is enabled in the switch. Value:
        """
        return pulumi.get(self, "enable_ipv6")

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> pulumi.Output[str]:
        """
        The IPv6 CIDR block of the VSwitch.
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @property
    @pulumi.getter(name="ipv6CidrBlockMask")
    def ipv6_cidr_block_mask(self) -> pulumi.Output[int]:
        """
        The IPv6 CIDR block of the VSwitch.
        """
        return pulumi.get(self, "ipv6_cidr_block_mask")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to create the default VSwitch. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated from provider version 1.119.0. New field 'vswitch_name' instead.""")
    def name(self) -> pulumi.Output[str]:
        """
        Field `name` has been deprecated from provider version 1.119.0. New field `vswitch_name` instead.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        The tags of VSwitch.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The VPC ID. **NOTE:** From version 1.233.0, if you do not set `is_default`, or set `is_default` to `false`, `vpc_id` is required.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchName")
    def vswitch_name(self) -> pulumi.Output[str]:
        """
        The name of the VSwitch.
        """
        return pulumi.get(self, "vswitch_name")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[str]:
        """
        The AZ for the VSwitch. **Note:** Required for a VPC VSwitch.
        """
        return pulumi.get(self, "zone_id")

